@@ -1,28 +1,15 @@
 /*
- * Copyright (C) 2017 David Faure <faure@kde.org>
+ * SPDX-FileCopyrightText: 2017 David Faure <faure@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #include "dict_object.h"
-#include <QDebug>
 #include <KLocalizedString>
+#include <QDebug>
 #include <QQuickWebEngineProfile>
-#include <QWebEngineUrlSchemeHandler>
 #include <QWebEngineUrlRequestJob>
-
+#include <QWebEngineUrlSchemeHandler>
 
 // The KDE4 applet could use "qstardict" if available, but I have no idea where this came from.
 static const char defaultDataEngine[] = "dict";
@@ -35,25 +22,25 @@ public:
         : QWebEngineUrlSchemeHandler(parent)
     {
     }
-    void requestStarted(QWebEngineUrlRequestJob *job) override {
+    void requestStarted(QWebEngineUrlRequestJob *job) override
+    {
         job->fail(QWebEngineUrlRequestJob::UrlInvalid);
         const QString word = job->requestUrl().path();
         emit wordClicked(word);
-   }
+    }
 
 Q_SIGNALS:
     void wordClicked(const QString &word);
 };
 
 DictObject::DictObject(QObject *parent)
-    : QObject(parent),
-    m_dataEngineName(QString::fromLatin1(defaultDataEngine))
+    : QObject(parent)
+    , m_dataEngineName(QString::fromLatin1(defaultDataEngine))
 {
     m_selectedDict = QStringLiteral("wn");
     m_webProfile = new QQuickWebEngineProfile(this);
     auto *schemeHandler = new DictSchemeHandler(this);
-    connect(schemeHandler, &DictSchemeHandler::wordClicked,
-            this, &DictObject::lookup);
+    connect(schemeHandler, &DictSchemeHandler::wordClicked, this, &DictObject::lookup);
     m_webProfile->installUrlSchemeHandler("dict", schemeHandler);
     m_dataEngine = dataEngine(m_dataEngineName); // Load it upfront so the config dialog can reuse this one
 }
@@ -88,13 +75,12 @@ QString DictObject::selectedDictionary() const
     return m_selectedDict;
 }
 
-void DictObject::setSelectedDictionary(const QString& dict)
+void DictObject::setSelectedDictionary(const QString &dict)
 {
     m_selectedDict = dict;
 }
 
-
-QQuickWebEngineProfile* DictObject::webProfile() const
+QQuickWebEngineProfile *DictObject::webProfile() const
 {
     return m_webProfile;
 }
