@@ -1,21 +1,7 @@
 /*
- * Copyright (C) 2020 Alexander Lohnau <alexander.lohnau@gmx.de>
+ * SPDX-FileCopyrightText: 2020 Alexander Lohnau <alexander.lohnau@gmx.de>
  *
- *   This library is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU Lesser General Public
- *   License as published by the Free Software Foundation; either
- *   version 2.1 of the License, or (at your option) version 3, or any
- *   later version accepted by the membership of KDE e.V. (or its
- *   successor approved by the membership of KDE e.V.), which shall
- *   act as a proxy defined in Section 6 of version 3 of the license.
- *
- *   This library is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *   Lesser General Public License for more details.
- *
- *   You should have received a copy of the GNU Lesser General Public
- *   License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ *   SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include <QTest>
@@ -28,7 +14,7 @@ using namespace KUnitConversion;
 
 class ConverterRunnerTest : public QObject
 {
-Q_OBJECT
+    Q_OBJECT
 private Q_SLOTS:
     void initTestCase();
 
@@ -55,7 +41,7 @@ void ConverterRunnerTest::initTestCase()
     setlocale(LC_ALL, "C.utf8");
     qputenv("LANG", "en_US");
     QLocale::setDefault(QLocale::English);
-    runner = new ConverterRunner(this, QVariantList());
+    runner = new ConverterRunner(this, KPluginMetaData(), QVariantList());
     runner->init();
 }
 
@@ -70,7 +56,7 @@ void ConverterRunnerTest::testMostCommonUnits()
 
     Converter converter;
     const auto lengthCategory = converter.category(KUnitConversion::LengthCategory);
-    QCOMPARE(context.matches().count(), lengthCategory.mostCommonUnits().count() -1);
+    QCOMPARE(context.matches().count(), lengthCategory.mostCommonUnits().count() - 1);
 }
 
 /*
@@ -83,7 +69,7 @@ void ConverterRunnerTest::testSpecificTargetUnit()
     runner->match(context);
 
     QCOMPARE(context.matches().count(), 1);
-    QCOMPARE(context.matches().first().text(), QStringLiteral("100 centimeters (cm)"));
+    QCOMPARE(context.matches().constFirst().text(), QStringLiteral("100 centimeters (cm)"));
 }
 
 /**
@@ -108,13 +94,13 @@ void ConverterRunnerTest::testCaseSensitiveUnits()
     runner->match(context);
 
     QCOMPARE(context.matches().count(), 1);
-    QCOMPARE(context.matches().first().text(), QStringLiteral("1,000,000,000 milliseconds (ms)"));
+    QCOMPARE(context.matches().constFirst().text(), QStringLiteral("1,000,000,000 milliseconds (ms)"));
 
     Plasma::RunnerContext context2;
     context2.setQuery(QStringLiteral("1,000,000,000milliseconds>Ms"));
     runner->match(context2);
     QCOMPARE(context2.matches().count(), 1);
-    QCOMPARE(context2.matches().first().text(), "1 megasecond (Ms)");
+    QCOMPARE(context2.matches().constFirst().text(), "1 megasecond (Ms)");
 }
 
 /**
@@ -136,7 +122,6 @@ void ConverterRunnerTest::testCurrency()
         currencyUnits << localCurrency;
     }
     QCOMPARE(context.matches().count(), currencyUnits.count() - 1);
-
 }
 
 /**
@@ -149,7 +134,7 @@ void ConverterRunnerTest::testLettersAndCurrency()
     runner->match(context);
 
     QCOMPARE(context.matches().count(), 1);
-    QVERIFY(context.matches().first().text().contains(QLatin1String("Canadian dollars (CAD)")));
+    QVERIFY(context.matches().constFirst().text().contains(QLatin1String("Canadian dollars (CAD)")));
 }
 
 /**
@@ -174,7 +159,7 @@ void ConverterRunnerTest::testFractions()
     runner->match(context);
 
     QCOMPARE(context.matches().count(), 1);
-    QCOMPARE(context.matches().first().text(), QStringLiteral("200 centimeters (cm)"));
+    QCOMPARE(context.matches().constFirst().text(), QStringLiteral("200 centimeters (cm)"));
 }
 
 /**
@@ -237,7 +222,7 @@ void ConverterRunnerTest::testNegativeValue()
     runner->match(context);
 
     QCOMPARE(context.matches().count(), 1);
-    QCOMPARE(context.matches().first().text(), "-400 centimeters (cm)");
+    QCOMPARE(context.matches().constFirst().text(), "-400 centimeters (cm)");
 }
 
 QTEST_MAIN(ConverterRunnerTest)
